==> humhub-1.12.0.tar.gz: humhub-1.12.0/protected/humhub/modules/admin/messages/pt-BR/base.php <==
<?php
return array (
  '<strong>Administration</strong> menu' => 'Menu de <strong>administração</strong>',
  '<strong>Maintenance</strong> Mode' => '<strong>Modo</strong> de manutenção',
  '<strong>Module</strong> Administration' => '',
  '<strong>Warning</strong> incomplete setup!' => '<strong>Aviso</strong> configuração incompleta!',
  'About' => 'Sobre',
  'Activate' => 'Ativar',
  'Add Licence Key' => '',
  'Admin' => 'Admin',
  'Administration' => 'Administração',
  'Administrative group' => 'Grupo administrativo',
  'Administrators' => 'Administradores',
  'Advanced' => 'Avançado',
  'Advanced settings' => 'Configurações avançadas',
  'Appearance' => 'Aparência',
  'Approval' => 'Aprovação',
  'Authentication' => 'Autenticação',
  'Back to overview' => 'Voltar para Visão Global',
  'Back to user overview' => 'Voltar para a visão global do usuário',
  'Base URL needs to begin with http:// or https://' => 'Endereço deve começar com http:// ou https://',
  'Basic' => 'Básico',
  'Caching' => 'Fazer cache',
  'Configure' => 'Configurar',
  'Cronjobs' => 'Tarefas agendadas',
  'Deactivate' => 'Desativar',
  'Default' => 'Padrão',
  'Default group for administrators of this HumHub Installation' => '',
  'Default group for all newly registered users of the network' => '',
  'Delete all' => 'Apagar tudo',
  'Delete selected rows' => 'Excluir linhas selecionadas',
  'Design' => 'Design',
  'Files' => 'Arquivos',
  'General' => 'Geral',
  'Groups' => 'Grupos',
  'Groups (Note: The Administrator group of this user can\'t be managed with your permissions)' => 'Grupos (Nota: O grupo Administrador deste usuário não pode ser gerenciado com suas permissões)',
  'Information' => 'Informação',
  'Invalid user state: {state}' => 'Estado de usuário inválido: {state}',
  'Invite' => 'Convite',
  'Invited by' => 'Convidado por',
  'Logging' => 'Registros de Log',
  'Logs' => 'Logs',
  'Mailing' => 'Correspondência',
  'Modules' => 'Módulos',
  'No modules installed yet. Install some to enhance the functionality!' => 'Nenhum módulo instalado ainda. Instale alguns para melhorar a funcionalidade!',
  'Notifications' => 'Notificações',
  'OEmbed' => 'OEmbed',
  'OEmbed providers' => 'Provedores Oembed',
  'Open documentation' => 'Documentação aberta',
  'Pending user registrations' => 'Registros de usuários pendentes',
  'People' => 'Pessoas',
  'Permissions' => 'Permissões',
  'Proxy' => 'Proxy',
  'Search' => 'Procurar',
  'Search...' => '',
  'Self test' => 'Auto teste',
  'Set as default' => 'Marcar como padrão',
  'Settings' => 'Configurações',
  'Sign up' => 'Registre-se',
  'Spaces' => 'Espaços',
  'Statistics' => 'Estatísticas',
  'The cron job for the background jobs (queue) does not seem to work properly.' => 'O trabalho cron para os trabalhos em segundo plano (fila) parece não funcionar corretamente.',
  'The cron job for the regular tasks (cron) does not seem to work properly.' => 'O trabalho cron para as tarefas regulares (cron) parece não funcionar corretamente.',
  'Uninstall' => 'Desinstalar',
  'User not found!' => 'Usuário não encontrado!',
  'Userprofiles' => 'Perfis de usuário',
  'Users' => 'Usuários',
);

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/admin/messages/pt-BR/base.php <==
<?php
return array (
  '<strong>Administration</strong> menu' => 'Menu de <strong>administração</strong>',
  '<strong>Maintenance</strong> Mode' => '<strong>Modo</strong> de manutenção',
  '<strong>Module</strong> Administration' => 'Administração do <strong>Módulo</strong>',
  '<strong>Warning</strong> incomplete setup!' => '<strong>Aviso</strong> configuração incompleta!',
  'About' => 'Sobre',
  'Activate' => 'Ativar',
  'Add Licence Key' => 'Adicionar chave de licença',
  'Admin' => 'Admin',
  'Administration' => 'Administração',
  'Administrative group' => 'Grupo administrativo',
  'Administrators' => 'Administradores',
  'Advanced' => 'Avançado',
  'Advanced settings' => 'Configurações avançadas',
  'Appearance' => 'Aparência',
  'Approval' => 'Aprovação',
  'Authentication' => 'Autenticação',
  'Back to overview' => 'Voltar para Visão Global',
  'Back to user overview' => 'Voltar para a visão global do usuário',
  'Base URL needs to begin with http:// or https://' => 'Endereço deve começar com http:// ou https://',
  'Basic' => 'Básico',
  'Caching' => 'Fazer cache',
  'Configure' => 'Configurar',
  'Cronjobs' => 'Tarefas agendadas',
  'Deactivate' => 'Desativar',
  'Default' => 'Padrão',
  'Default group for administrators of this HumHub Installation' => 'Grupo padrão para administradores desta instalação do HumHub',
  'Default group for all newly registered users of the network' => 'Grupo padrão para todos os usuários recém registrados na rede',
  'Delete all' => 'Apagar tudo',
  'Delete selected rows' => 'Excluir linhas selecionadas',
  'Design' => 'Design',
  'Files' => 'Arquivos',
  'General' => 'Geral',
  'Groups' => 'Grupos',
  'Groups (Note: The Administrator group of this user can\'t be managed with your permissions)' => 'Grupos (Nota: O grupo Administrador deste usuário não pode ser gerenciado com suas permissões)',
  'Information' => 'Informação',
  'Invalid user state: {state}' => 'Estado de usuário inválido: {state}',
  'Invite' => 'Convite',
  'Invited by' => 'Convidado por',
  'Logging' => 'Registros de Log',
  'Logs' => 'Logs',
  'Mailing' => 'Correspondência',
  'Modules' => 'Módulos',
  'No modules installed yet. Install some to enhance the functionality!' => 'Nenhum módulo instalado ainda. Instale alguns para melhorar a funcionalidade!',
  'Notifications' => 'Notificações',
  'OEmbed' => 'OEmbed',
  'OEmbed providers' => 'Provedores Oembed',
  'Open documentation' => 'Documentação aberta',
  'Pending user registrations' => 'Registros de usuários pendentes',
  'People' => 'Pessoas',
  'Permissions' => 'Permissões',
  'Proxy' => 'Proxy',
  'Search' => 'Procurar',
  'Search...' => 'Procurar...',
  'Self test' => 'Auto teste',
  'Set as default' => 'Marcar como padrão',
  'Settings' => 'Configurações',
  'Sign up' => 'Registre-se',
  'Spaces' => 'Espaços',
  'Statistics' => 'Estatísticas',
  'The cron job for the background jobs (queue) does not seem to work properly.' => 'O trabalho cron para os trabalhos em segundo plano (fila) parece não funcionar corretamente.',
  'The cron job for the regular tasks (cron) does not seem to work properly.' => 'O trabalho cron para as tarefas regulares (cron) parece não funcionar corretamente.',
  'Uninstall' => 'Desinstalar',
  'User not found!' => 'Usuário não encontrado!',
  'Userprofiles' => 'Perfis de usuário',
  'Users' => 'Usuários',
);
